@@ -16,8 +16,6 @@ def deploy_to_pypi(setup_path=None):
 
     Args:
         setup_path((str, pathlib.Path)): Function suppose, that there is a setup.py in cwd. If not, pass path to setup.py.
-        username
-        password
     """
     try:
         os.environ['TWINE_USERNAME']
@@ -39,6 +37,7 @@ def deploy_to_pypi(setup_path=None):
     try:
         shutil.rmtree(setup_path / 'dist')
         shutil.rmtree(setup_path / 'build')
+
     except Exception:
         pass
 
